/// <reference types="node" resolution-mode="require"/>
import { URLSearchParams } from 'url';
import Browser from './browser/Browser.js';
import BrowserContext from './browser/BrowserContext.js';
import BrowserFrame from './browser/BrowserFrame.js';
import BrowserPage from './browser/BrowserPage.js';
import DetachedBrowser from './browser/detached-browser/DetachedBrowser.js';
import DetachedBrowserContext from './browser/detached-browser/DetachedBrowserContext.js';
import DetachedBrowserFrame from './browser/detached-browser/DetachedBrowserFrame.js';
import DetachedBrowserPage from './browser/detached-browser/DetachedBrowserPage.js';
import BrowserErrorCaptureEnum from './browser/enums/BrowserErrorCaptureEnum.js';
import BrowserNavigationCrossOriginPolicyEnum from './browser/enums/BrowserNavigationCrossOriginPolicyEnum.js';
import Clipboard from './clipboard/Clipboard.js';
import ClipboardItem from './clipboard/ClipboardItem.js';
import VirtualConsole from './console/VirtualConsole.js';
import VirtualConsolePrinter from './console/VirtualConsolePrinter.js';
import VirtualConsoleLogLevelEnum from './console/enums/VirtualConsoleLogLevelEnum.js';
import VirtualConsoleLogTypeEnum from './console/enums/VirtualConsoleLogTypeEnum.js';
import CSSRule from './css/CSSRule.js';
import CSSStyleSheet from './css/CSSStyleSheet.js';
import CSSStyleDeclaration from './css/declaration/CSSStyleDeclaration.js';
import CSSContainerRule from './css/rules/CSSContainerRule.js';
import CSSFontFaceRule from './css/rules/CSSFontFaceRule.js';
import CSSKeyframeRule from './css/rules/CSSKeyframeRule.js';
import CSSKeyframesRule from './css/rules/CSSKeyframesRule.js';
import CSSMediaRule from './css/rules/CSSMediaRule.js';
import CSSStyleRule from './css/rules/CSSStyleRule.js';
import CSSSupportsRule from './css/rules/CSSSupportsRule.js';
import CustomElementRegistry from './custom-element/CustomElementRegistry.js';
import DOMParser from './dom-parser/DOMParser.js';
import DataTransfer from './event/DataTransfer.js';
import DataTransferItem from './event/DataTransferItem.js';
import DataTransferItemList from './event/DataTransferItemList.js';
import Event from './event/Event.js';
import EventPhaseEnum from './event/EventPhaseEnum.js';
import EventTarget from './event/EventTarget.js';
import Touch from './event/Touch.js';
import UIEvent from './event/UIEvent.js';
import AnimationEvent from './event/events/AnimationEvent.js';
import ClipboardEvent from './event/events/ClipboardEvent.js';
import CustomEvent from './event/events/CustomEvent.js';
import ErrorEvent from './event/events/ErrorEvent.js';
import FocusEvent from './event/events/FocusEvent.js';
import InputEvent from './event/events/InputEvent.js';
import KeyboardEvent from './event/events/KeyboardEvent.js';
import MouseEvent from './event/events/MouseEvent.js';
import ProgressEvent from './event/events/ProgressEvent.js';
import SubmitEvent from './event/events/SubmitEvent.js';
import TouchEvent from './event/events/TouchEvent.js';
import WheelEvent from './event/events/WheelEvent.js';
import DOMException from './exception/DOMException.js';
import AbortController from './fetch/AbortController.js';
import AbortSignal from './fetch/AbortSignal.js';
import Headers from './fetch/Headers.js';
import Request from './fetch/Request.js';
import Response from './fetch/Response.js';
import Blob from './file/Blob.js';
import File from './file/File.js';
import FileReader from './file/FileReader.js';
import FormData from './form-data/FormData.js';
import History from './history/History.js';
import MutationObserver from './mutation-observer/MutationObserver.js';
import MutationRecord from './mutation-observer/MutationRecord.js';
import Attr from './nodes/attr/Attr.js';
import Comment from './nodes/comment/Comment.js';
import DocumentFragment from './nodes/document-fragment/DocumentFragment.js';
import DocumentType from './nodes/document-type/DocumentType.js';
import Document from './nodes/document/Document.js';
import DOMRect from './nodes/element/DOMRect.js';
import Element from './nodes/element/Element.js';
import HTMLCollection from './nodes/element/HTMLCollection.js';
import HTMLAnchorElement from './nodes/html-anchor-element/HTMLAnchorElement.js';
import HTMLAudioElement from './nodes/html-audio-element/HTMLAudioElement.js';
import HTMLBaseElement from './nodes/html-base-element/HTMLBaseElement.js';
import HTMLButtonElement from './nodes/html-button-element/HTMLButtonElement.js';
import HTMLDialogElement from './nodes/html-dialog-element/HTMLDialogElement.js';
import HTMLDocument from './nodes/html-document/HTMLDocument.js';
import HTMLElement from './nodes/html-element/HTMLElement.js';
import HTMLFormControlsCollection from './nodes/html-form-element/HTMLFormControlsCollection.js';
import HTMLFormElement from './nodes/html-form-element/HTMLFormElement.js';
import HTMLIFrameElement from './nodes/html-iframe-element/HTMLIFrameElement.js';
import HTMLImageElement from './nodes/html-image-element/HTMLImageElement.js';
import Image from './nodes/html-image-element/Image.js';
import FileList from './nodes/html-input-element/FileList.js';
import HTMLInputElement from './nodes/html-input-element/HTMLInputElement.js';
import HTMLLabelElement from './nodes/html-label-element/HTMLLabelElement.js';
import HTMLLinkElement from './nodes/html-link-element/HTMLLinkElement.js';
import HTMLMediaElement from './nodes/html-media-element/HTMLMediaElement.js';
import HTMLMetaElement from './nodes/html-meta-element/HTMLMetaElement.js';
import HTMLOptGroupElement from './nodes/html-opt-group-element/HTMLOptGroupElement.js';
import HTMLOptionElement from './nodes/html-option-element/HTMLOptionElement.js';
import HTMLScriptElement from './nodes/html-script-element/HTMLScriptElement.js';
import HTMLSelectElement from './nodes/html-select-element/HTMLSelectElement.js';
import HTMLSlotElement from './nodes/html-slot-element/HTMLSlotElement.js';
import HTMLStyleElement from './nodes/html-style-element/HTMLStyleElement.js';
import HTMLTemplateElement from './nodes/html-template-element/HTMLTemplateElement.js';
import HTMLTextAreaElement from './nodes/html-text-area-element/HTMLTextAreaElement.js';
import HTMLUnknownElement from './nodes/html-unknown-element/HTMLUnknownElement.js';
import HTMLVideoElement from './nodes/html-video-element/HTMLVideoElement.js';
import Node from './nodes/node/Node.js';
import ProcessingInstruction from './nodes/processing-instruction/ProcessingInstruction.js';
import ShadowRoot from './nodes/shadow-root/ShadowRoot.js';
import SVGDocument from './nodes/svg-document/SVGDocument.js';
import SVGElement from './nodes/svg-element/SVGElement.js';
import SVGGraphicsElement from './nodes/svg-element/SVGGraphicsElement.js';
import SVGSVGElement from './nodes/svg-element/SVGSVGElement.js';
import Text from './nodes/text/Text.js';
import XMLDocument from './nodes/xml-document/XMLDocument.js';
import PermissionStatus from './permissions/PermissionStatus.js';
import Permissions from './permissions/Permissions.js';
import Range from './range/Range.js';
import ResizeObserver from './resize-observer/ResizeObserver.js';
import Screen from './screen/Screen.js';
import Selection from './selection/Selection.js';
import Storage from './storage/Storage.js';
import NodeFilter from './tree-walker/NodeFilter.js';
import NodeIterator from './tree-walker/NodeIterator.js';
import TreeWalker from './tree-walker/TreeWalker.js';
import Location from './url/Location.js';
import URL from './url/URL.js';
import BrowserWindow from './window/BrowserWindow.js';
import GlobalWindow from './window/GlobalWindow.js';
import Window from './window/Window.js';
import XMLParser from './xml-parser/XMLParser.js';
import XMLSerializer from './xml-serializer/XMLSerializer.js';
import type IBrowser from './browser/types/IBrowser.js';
import type IBrowserContext from './browser/types/IBrowserContext.js';
import type IBrowserFrame from './browser/types/IBrowserFrame.js';
import type IBrowserPage from './browser/types/IBrowserPage.js';
import type IBrowserSettings from './browser/types/IBrowserSettings.js';
import type IOptionalBrowserSettings from './browser/types/IOptionalBrowserSettings.js';
import type IEventInit from './event/IEventInit.js';
import type IEventListener from './event/IEventListener.js';
import type ITouchInit from './event/ITouchInit.js';
import type IUIEventInit from './event/IUIEventInit.js';
import type IAnimationEventInit from './event/events/IAnimationEventInit.js';
import type IClipboardEventInit from './event/events/IClipboardEventInit.js';
import type ICustomEventInit from './event/events/ICustomEventInit.js';
import type IErrorEventInit from './event/events/IErrorEventInit.js';
import type IFocusEventInit from './event/events/IFocusEventInit.js';
import type IInputEventInit from './event/events/IInputEventInit.js';
import type IKeyboardEventInit from './event/events/IKeyboardEventInit.js';
import type IMouseEventInit from './event/events/IMouseEventInit.js';
import type IProgressEventInit from './event/events/IProgressEventInit.js';
import type ISubmitEventInit from './event/events/ISubmitEventInit.js';
import type ITouchEventInit from './event/events/ITouchEventInit.js';
import type IWheelEventInit from './event/events/IWheelEventInit.js';
import type IHeaders from './fetch/types/IHeaders.js';
import type IRequest from './fetch/types/IRequest.js';
import type IResponse from './fetch/types/IResponse.js';
import type IAttr from './nodes/attr/IAttr.js';
import type IComment from './nodes/comment/IComment.js';
import type IDocumentFragment from './nodes/document-fragment/IDocumentFragment.js';
import type IDocumentType from './nodes/document-type/IDocumentType.js';
import type IDocument from './nodes/document/IDocument.js';
import type IElement from './nodes/element/IElement.js';
import type IHTMLCollection from './nodes/element/IHTMLCollection.js';
import type IHTMLAnchorElement from './nodes/html-anchor-element/IHTMLAnchorElement.js';
import type IHTMLAudioElement from './nodes/html-audio-element/IHTMLAudioElement.js';
import type IHTMLBaseElement from './nodes/html-base-element/IHTMLBaseElement.js';
import type IHTMLButtonElement from './nodes/html-button-element/IHTMLButtonElement.js';
import type IHTMLDialogElement from './nodes/html-dialog-element/IHTMLDialogElement.js';
import type IHTMLElement from './nodes/html-element/IHTMLElement.js';
import type IHTMLFormControlsCollection from './nodes/html-form-element/IHTMLFormControlsCollection.js';
import type IHTMLFormElement from './nodes/html-form-element/IHTMLFormElement.js';
import type IHTMLIFrameElement from './nodes/html-iframe-element/IHTMLIFrameElement.js';
import type IHTMLImageElement from './nodes/html-image-element/IHTMLImageElement.js';
import type IFileList from './nodes/html-input-element/IFileList.js';
import type IHTMLInputElement from './nodes/html-input-element/IHTMLInputElement.js';
import type IHTMLLabelElement from './nodes/html-label-element/IHTMLLabelElement.js';
import type IHTMLLinkElement from './nodes/html-link-element/IHTMLLinkElement.js';
import type IHTMLMediaElement from './nodes/html-media-element/IHTMLMediaElement.js';
import type IHTMLMetaElement from './nodes/html-meta-element/IHTMLMetaElement.js';
import type IHTMLOptGroupElement from './nodes/html-opt-group-element/IHTMLOptGroupElement.js';
import type IHTMLOptionElement from './nodes/html-option-element/IHTMLOptionElement.js';
import type IHTMLSelectElement from './nodes/html-select-element/IHTMLSelectElement.js';
import type IHTMLSlotElement from './nodes/html-slot-element/IHTMLSlotElement.js';
import type IHTMLStyleElement from './nodes/html-style-element/IHTMLStyleElement.js';
import type IHTMLTemplateElement from './nodes/html-template-element/IHTMLTemplateElement.js';
import type IHTMLTextAreaElement from './nodes/html-text-area-element/IHTMLTextAreaElement.js';
import type IHTMLVideoElement from './nodes/html-video-element/IHTMLVideoElement.js';
import type INode from './nodes/node/INode.js';
import type INodeList from './nodes/node/INodeList.js';
import type IProcessingInstruction from './nodes/processing-instruction/IProcessingInstruction.js';
import type IShadowRoot from './nodes/shadow-root/IShadowRoot.js';
import type ISVGElement from './nodes/svg-element/ISVGElement.js';
import type ISVGGraphicsElement from './nodes/svg-element/ISVGGraphicsElement.js';
import type ISVGSVGElement from './nodes/svg-element/ISVGSVGElement.js';
import type IText from './nodes/text/IText.js';
import type IBrowserWindow from './window/IBrowserWindow.js';
import type ICrossOriginBrowserWindow from './window/ICrossOriginBrowserWindow.js';
import type IWindow from './window/IWindow.js';
export type { IAnimationEventInit, IAttr, IBrowser, IBrowserContext, IBrowserFrame, IBrowserPage, IBrowserSettings, IBrowserWindow, IClipboardEventInit, IComment, ICrossOriginBrowserWindow, ICustomEventInit, IDocument, IDocumentFragment, IDocumentType, IElement, IErrorEventInit, IEventInit, IEventListener, IFileList, IFocusEventInit, IHTMLAnchorElement, IHTMLAudioElement, IHTMLBaseElement, IHTMLButtonElement, IHTMLCollection, IHTMLDialogElement, IHTMLElement, IHTMLFormControlsCollection, IHTMLFormElement, IHTMLIFrameElement, IHTMLImageElement, IHTMLInputElement, IHTMLLabelElement, IHTMLLinkElement, IHTMLMediaElement, IHTMLMetaElement, IHTMLOptGroupElement, IHTMLOptionElement, IHTMLSelectElement, IHTMLSlotElement, IHTMLStyleElement, IHTMLTemplateElement, IHTMLTextAreaElement, IHTMLVideoElement, IHeaders, IInputEventInit, IKeyboardEventInit, IMouseEventInit, INode, INodeList, IOptionalBrowserSettings, IProcessingInstruction, IProgressEventInit, IRequest, IResponse, ISVGElement, ISVGGraphicsElement, ISVGSVGElement, IShadowRoot, ISubmitEventInit, IText, ITouchEventInit, ITouchInit, IUIEventInit, IWheelEventInit, IWindow };
export { AbortController, AbortSignal, AnimationEvent, Attr, Blob, Browser, BrowserContext, BrowserErrorCaptureEnum, BrowserFrame, BrowserNavigationCrossOriginPolicyEnum, BrowserPage, BrowserWindow, CSSContainerRule, CSSFontFaceRule, CSSKeyframeRule, CSSKeyframesRule, CSSMediaRule, CSSRule, CSSStyleDeclaration, CSSStyleRule, CSSStyleSheet, CSSSupportsRule, Clipboard, ClipboardEvent, ClipboardItem, Comment, CustomElementRegistry, CustomEvent, DOMException, DOMParser, DOMRect, DataTransfer, DataTransferItem, DataTransferItemList, DetachedBrowser, DetachedBrowserContext, DetachedBrowserFrame, DetachedBrowserPage, Document, DocumentFragment, DocumentType, Element, ErrorEvent, Event, EventPhaseEnum, EventTarget, File, FileList, FileReader, FocusEvent, FormData, GlobalWindow, HTMLAnchorElement, HTMLElement as HTMLAreaElement, HTMLAudioElement, HTMLElement as HTMLBRElement, HTMLBaseElement, HTMLElement as HTMLBodyElement, HTMLButtonElement, HTMLElement as HTMLCanvasElement, HTMLCollection, HTMLElement as HTMLDListElement, HTMLElement as HTMLDataElement, HTMLElement as HTMLDataListElement, HTMLElement as HTMLDetailsElement, HTMLDialogElement, HTMLElement as HTMLDirectoryElement, HTMLElement as HTMLDivElement, HTMLDocument, HTMLElement, HTMLElement as HTMLEmbedElement, HTMLElement as HTMLFieldSetElement, HTMLElement as HTMLFontElement, HTMLFormControlsCollection, HTMLFormElement, HTMLElement as HTMLFrameElement, HTMLElement as HTMLFrameSetElement, HTMLElement as HTMLHRElement, HTMLElement as HTMLHeadElement, HTMLElement as HTMLHeadingElement, HTMLElement as HTMLHtmlElement, HTMLIFrameElement, HTMLImageElement, HTMLInputElement, HTMLElement as HTMLLIElement, HTMLLabelElement, HTMLElement as HTMLLegendElement, HTMLLinkElement, HTMLElement as HTMLMapElement, HTMLElement as HTMLMarqueeElement, HTMLMediaElement, HTMLElement as HTMLMenuElement, HTMLMetaElement, HTMLElement as HTMLMeterElement, HTMLElement as HTMLModElement, HTMLElement as HTMLOListElement, HTMLElement as HTMLObjectElement, HTMLOptGroupElement, HTMLOptionElement, HTMLElement as HTMLOutputElement, HTMLElement as HTMLParagraphElement, HTMLElement as HTMLParamElement, HTMLElement as HTMLPictureElement, HTMLElement as HTMLPreElement, HTMLElement as HTMLProgressElement, HTMLElement as HTMLQuoteElement, HTMLScriptElement, HTMLSelectElement, HTMLSlotElement, HTMLElement as HTMLSourceElement, HTMLElement as HTMLSpanElement, HTMLStyleElement, HTMLElement as HTMLTableCaptionElement, HTMLElement as HTMLTableCellElement, HTMLElement as HTMLTableColElement, HTMLElement as HTMLTableElement, HTMLElement as HTMLTableRowElement, HTMLElement as HTMLTableSectionElement, HTMLTemplateElement, HTMLTextAreaElement, HTMLElement as HTMLTimeElement, HTMLElement as HTMLTitleElement, HTMLElement as HTMLTrackElement, HTMLElement as HTMLUListElement, HTMLUnknownElement, HTMLVideoElement, Headers, History, Image, InputEvent, KeyboardEvent, Location, MouseEvent, MutationObserver, MutationRecord, Node, NodeFilter, NodeIterator, PermissionStatus, Permissions, ProcessingInstruction, ProgressEvent, Range, Request, ResizeObserver, Response, SVGDocument, SVGElement, SVGGraphicsElement, SVGSVGElement, Screen, Selection, ShadowRoot, Storage, SubmitEvent, Text, Touch, TouchEvent, TreeWalker, UIEvent, URL, URLSearchParams, VirtualConsole, VirtualConsoleLogLevelEnum, VirtualConsoleLogTypeEnum, VirtualConsolePrinter, WheelEvent, Window, XMLDocument, XMLParser, XMLSerializer };
//# sourceMappingURL=index.d.ts.map